[][src]Module wasm_pack::command::build

Implementation of the wasm-pack build command.

Structs

Build

Everything required to configure and run the wasm-pack build command.

BuildOptions

Everything required to configure and run the wasm-pack build command.

Enums

BuildMode

The BuildMode determines which mode of initialization we are running, and what build and install steps we perform.

BuildProfile

The build profile controls whether optimizations, debug info, and assertions are enabled or disabled.

Target

What sort of output we're going to be generating and flags we're invoking wasm-bindgen with.