[−][src]Enum wasm_pack::command::build::Target
What sort of output we're going to be generating and flags we're invoking
wasm-bindgen with.
Variants
Default output mode or --target bundler, indicates output will be
used with a bundle in a later step.
Correspond to --target web where the output is natively usable as an
ES module in a browser and the wasm is manually instantiated.
Correspond to --target nodejs where the output is natively usable as
a Node.js module loaded with require.
Correspond to --target no-modules where the output is natively usable
in a browser but pollutes the global namespace and must be manually
instantiated.