Struct wasm_pack::command::build::BuildOptions
source · pub struct BuildOptions {Show 15 fields
pub path: Option<PathBuf>,
pub scope: Option<String>,
pub mode: InstallMode,
pub disable_dts: bool,
pub weak_refs: bool,
pub reference_types: bool,
pub target: Target,
pub debug: bool,
pub dev: bool,
pub release: bool,
pub profiling: bool,
pub out_dir: String,
pub out_name: Option<String>,
pub no_pack: bool,
pub extra_options: Vec<String>,
}Expand description
Everything required to configure and run the wasm-pack build command.
Fields
path: Option<PathBuf>The path to the Rust crate. If not set, searches up the path from the current directory.
scope: Option<String>The npm scope to use in package.json, if any.
mode: InstallModeSets steps to be run. [possible values: no-install, normal, force]
disable_dts: boolBy default a *.d.ts file is generated for the generated JS file, but this flag will disable generating this TypeScript file.
weak_refs: boolEnable usage of the JS weak references proposal.
reference_types: boolEnable usage of WebAssembly reference types.
target: TargetSets the target environment. [possible values: bundler, nodejs, web, no-modules]
debug: boolDeprecated. Renamed to --dev.
dev: boolCreate a development build. Enable debug info, and disable optimizations.
release: boolCreate a release build. Enable optimizations and disable debug info.
profiling: boolCreate a profiling build. Enable optimizations and debug info.
out_dir: StringSets the output directory with a relative path.
out_name: Option<String>Sets the output file names. Defaults to package name.
no_pack: boolOption to not generate a package.json
extra_options: Vec<String>List of extra options to pass to cargo build