pub enum Command {
    Build(BuildOptions),
    Pack {
        path: Option<PathBuf>,
    },
    Generate {
        name: String,
        template: String,
        mode: InstallMode,
    },
    Publish {
        target: String,
        access: Option<Access>,
        tag: Option<String>,
        path: Option<PathBuf>,
    },
    Login {
        registry: Option<String>,
        scope: Option<String>,
        auth_type: Option<String>,
    },
    Test(TestOptions),
}
The various kinds of commands that wasm-pack can execute.

Variants



Build(BuildOptions)

🏗️ build your npm package!



Pack

Fields

path: Option<PathBuf>

The path to the Rust crate. If not set, searches up the path from the current directory.

🍱 create a tar of your npm package but don’t publish!



Generate

Fields

name: String

The name of the project

template: String

The URL to the template

mode: InstallMode

Should we install or check the presence of binary tools. [possible values: no-install, normal, force]

🐑 create a new project with a template



Publish

Fields

target: String

Sets the target environment. [possible values: bundler, nodejs, web, no-modules]

access: Option<Access>

The access level for the package to be published

tag: Option<String>

The distribution tag being used for publishing. See https://docs.npmjs.com/cli/dist-tag

path: Option<PathBuf>

The path to the Rust crate. If not set, searches up the path from the current directory.

🎆 pack up your npm package and publish!



Login

Fields

registry: Option<String>

Default: ‘https://registry.npmjs.org/’. The base URL of the npm package registry. If scope is also specified, this registry will only be used for packages with that scope. scope defaults to the scope of the project directory you’re currently in, if any.

scope: Option<String>

Default: none. If specified, the user and login credentials given will be associated with the specified scope.

auth_type: Option<String>

Default: ‘legacy’. Type: ‘legacy’, ‘sso’, ‘saml’, ‘oauth’. What authentication strategy to use with adduser/login. Some npm registries (for example, npmE) might support alternative auth strategies besides classic username/password entry in legacy npm.

👤 Add an npm registry user account! (aliases: adduser, add-user)



Test(TestOptions)

👩‍🔬 test your wasm!