Utility functions for commands.
Functions
- Construct our
pkgdirectory in the crate. - Render a
Durationto a form suitable for display on a console - Locates the pkg directory from a specific path Returns None if unable to find the ‘pkg’ directory
- If an explicit path is given, then use it, otherwise assume the current directory is the crate path.