Function wasm_pack::command::utils::get_crate_path
source · pub fn get_crate_path(path: Option<PathBuf>) -> Result<PathBuf>Expand description
If an explicit path is given, then use it, otherwise assume the current directory is the crate path.