[][src]Function wasm_pack::command::utils::set_crate_path

pub fn set_crate_path(path: Option<PathBuf>) -> Result<PathBuf, Error>

If an explicit path is given, then use it, otherwise assume the current directory is the crate path.