[][src]Module wasm_pack::install

Functionality related to installing prebuilt binaries and/or running cargo install.

Enums

InstallMode

The InstallMode determines which mode of initialization we are running, and what install steps we perform.

Status

Possible outcomes of attempting to find/install a tool

Tool

Represents the set of CLI tools wasm-pack uses

Functions

cargo_install

Use cargo install to install the tool locally into the given crate.

check_version

Check if the tool dependency is locally satisfied.

download_prebuilt

Downloads a precompiled copy of the tool, if available.

download_prebuilt_or_cargo_install

Install a cargo CLI tool

get_cli_version

Fetches the version of a CLI tool

get_tool_path

Handles possible installs status and returns the download or a error message