pub struct Cli {
pub cmd: Command,
pub verbosity: u8,
pub quiet: bool,
pub log_level: LogLevel,
}Expand description
📦 ✨ pack and publish your wasm!
Fields
cmd: CommandThe subcommand to run.
verbosity: u8Log verbosity is based off the number of v used
quiet: boolNo output printed to stdout
log_level: LogLevelThe maximum level of messages that should be logged by wasm-pack. [possible values: info, warn, error]