Module webdriver

Module webdriver 

Getting WebDriver client binaries.

Functions

get_or_install_chromedriver
Get the path to an existing chromedriver, or install it if no existing binary is found or if there is a new binary version.
get_or_install_geckodriver
Get the path to an existing geckodriver, or install it if no existing binary is found or if there is a new binary version.
get_safaridriver
Get the path to an existing safaridriver.
install_chromedriver
Download and install a pre-built chromedriver binary.
install_geckodriver
Download and install a pre-built geckodriver binary.