[][src]Struct wasm_pack::command::build::BuildOptions

pub struct BuildOptions {
    pub path: Option<PathBuf>,
    pub scope: Option<String>,
    pub mode: BuildMode,
    pub disable_dts: bool,
    pub target: Target,
    pub debug: bool,
    pub dev: bool,
    pub release: bool,
    pub profiling: bool,
    pub out_dir: String,
    pub out_name: Option<String>,
    pub extra_options: Vec<String>,
}

Everything required to configure and run the wasm-pack build command.

Fields

path: Option<PathBuf>

The path to the Rust crate.

scope: Option<String>

The npm scope to use in package.json, if any.

mode: BuildMode

Sets steps to be run. [possible values: no-install, normal, force]

disable_dts: bool

By default a *.d.ts file is generated for the generated JS file, but this flag will disable generating this TypeScript file.

target: Target

Sets the target environment. [possible values: browser, nodejs, web, no-modules]

debug: bool

Deprecated. Renamed to --dev.

dev: bool

Create a development build. Enable debug info, and disable optimizations.

release: bool

Create a release build. Enable optimizations and disable debug info.

profiling: bool

Create a profiling build. Enable optimizations and debug info.

out_dir: String

Sets the output directory with a relative path.

out_name: Option<String>

Sets the output file names. Defaults to package name.

extra_options: Vec<String>

List of extra options to pass to cargo build