pub enum Command {
Build(BuildOptions),
Pack {
path: Option<PathBuf>,
},
Generate {
name: String,
template: String,
mode: InstallMode,
},
Publish {
target: String,
access: Option<Access>,
tag: Option<String>,
path: Option<PathBuf>,
},
Login {
registry: Option<String>,
scope: Option<String>,
auth_type: Option<String>,
},
Test(TestOptions),
}Expand description
The various kinds of commands that wasm-pack can execute.
Variants
Build(BuildOptions)
🏗️ build your npm package!
Pack
Fields
🍱 create a tar of your npm package but don’t publish!
Generate
Fields

mode: InstallModeShould we install or check the presence of binary tools. [possible values: no-install, normal, force]
🐑 create a new project with a template
Publish
Fields
🎆 pack up your npm package and publish!
Login
Fields

registry: Option<String>Default: ‘https://registry.npmjs.org/’. The base URL of the npm package registry. If scope is also specified, this registry will only be used for packages with that scope. scope defaults to the scope of the project directory you’re currently in, if any.
👤 Add an npm registry user account! (aliases: adduser, add-user)
Test(TestOptions)
👩🔬 test your wasm!