[−][src]Enum wasm_pack::command::Command
The various kinds of commands that wasm-pack can execute.
Variants
Build(BuildOptions)ποΈ build your npm package!
Packπ± create a tar of your npm package but don't publish!
Fields of Pack
Publishπ pack up your npm package and publish!
Fields of Publish
Loginπ€ Add an npm registry user account! (aliases: adduser, add-user)
Fields of Login
registry: Option<String>Default: 'https://registry.npmjs.org/'. The base URL of the npm package registry. If scope is also specified, this registry will only be used for packages with that scope. scope defaults to the scope of the project directory you're currently in, if any.
scope: Option<String>Default: none. If specified, the user and login credentials given will be associated with the specified scope.
always_auth: boolIf specified, save configuration indicating that all requests to the given registry should include authorization information. Useful for private registries. Can be used with --registry and / or --scope
auth_type: Option<String>Default: 'legacy'. Type: 'legacy', 'sso', 'saml', 'oauth'. What authentication strategy to use with adduser/login. Some npm registries (for example, npmE) might support alternative auth strategies besides classic username/password entry in legacy npm.
Test(TestOptions)π©βπ¬ test your wasm!