[−][src]Struct wasm_pack::command::test::TestOptions
Everything required to configure the wasm-pack test command.
Fields
path: Option<PathBuf>The path to the Rust crate.
node: boolRun the tests in Node.js.
firefox: boolRun the tests in Firefox. This machine must have a Firefox installation.
If the geckodriver WebDriver client is not on the $PATH, and not
specified with --geckodriver, then wasm-pack will download a local
copy.
geckodriver: Option<PathBuf>The path to the geckodriver WebDriver client for testing in
Firefox. Implies --firefox.
chrome: boolRun the tests in Chrome. This machine must have a Chrome installation.
If the chromedriver WebDriver client is not on the $PATH, and not
specified with --chromedriver, then wasm-pack will download a local
copy.
chromedriver: Option<PathBuf>The path to the chromedriver WebDriver client for testing in
Chrome. Implies --chrome.
safari: boolRun the tests in Safari. This machine must have a Safari installation,
and the safaridriver WebDriver client must either be on the $PATH or
specified explicitly with the --safaridriver flag. wasm-pack cannot
download the safaridriver WebDriver client for you.
safaridriver: Option<PathBuf>The path to the safaridriver WebDriver client for testing in
Safari. Implies --safari.
headless: boolWhen running browser tests, run the browser in headless mode without any UI or windows.
mode: BuildModeSets steps to be run. [possible values: no-install, normal]
release: boolBuild with the release profile.
extra_options: Vec<String>List of extra options to pass to cargo test