[][src]Module wasm_pack::command::utils

Utility functions for commands.

Functions

create_pkg_dir

Construct our pkg directory in the crate.

elapsed

Render a Duration to a form suitable for display on a console

find_pkg_directory

Locates the pkg directory from a specific path Returns None if unable to find the 'pkg' directory

get_crate_path

If an explicit path is given, then use it, otherwise assume the current directory is the crate path.