Getting WebDriver client binaries.
Functions
- get_
or_ install_ chromedriver - Get the path to an existing
chromedriver, or install it if no existing binary is found or if there is a new binary version. - get_
or_ install_ geckodriver - Get the path to an existing
geckodriver, or install it if no existing binary is found or if there is a new binary version. - get_
safaridriver - Get the path to an existing
safaridriver. - install_
chromedriver - Download and install a pre-built
chromedriverbinary. - install_
geckodriver - Download and install a pre-built
geckodriverbinary.